@@ -66,25 +66,27 @@ __inline__ static void term_flush (void) {
 #define TERM_SGR_GCHAR		13
 #define TERM_SGR_ALTCHAR_ON	14
 #define TERM_SGR_ALTCHAR_OFF	15
-#define TERM_SGR_MAXVAL		16
+#define TERM_SGR_ITALIC_ON	16
+#define TERM_SGR_ITALIC_OFF	17
+#define TERM_SGR_MAXVAL		18
 
-#define TERM_CAN_CUP		1 << 0
-#define TERM_CAN_CLEAR		1 << 1
-#define TERM_CAN_CLREOL		1 << 2
-#define TERM_CAN_RIGHT		1 << 3
-#define TERM_CAN_LEFT		1 << 4
-#define TERM_CAN_SCROLL		1 << 5
-#define TERM_CAN_DELETE		1 << 6
-#define TERM_CAN_INSERT		1 << 7
-#define TERM_CAN_DELLINES	1 << 8
-#define TERM_CAN_INSLINES	1 << 9
-#define TERM_CAN_REPEAT		1 << 10
-#define TERM_CAN_BOLD		1 << 11
-#define TERM_CAN_BLINK		1 << 12
-#define TERM_CAN_UNDL		1 << 13
-#define TERM_CAN_REVERSE	1 << 14
-#define TERM_CAN_COLOR		1 << 15
-#define TERM_CAN_GCHAR		1 << 16
+#define TERM_CAN_CUP		(1 << 0)
+#define TERM_CAN_CLEAR		(1 << 1)
+#define TERM_CAN_CLREOL		(1 << 2)
+#define TERM_CAN_RIGHT		(1 << 3)
+#define TERM_CAN_LEFT		(1 << 4)
+#define TERM_CAN_SCROLL		(1 << 5)
+#define TERM_CAN_DELETE		(1 << 6)
+#define TERM_CAN_INSERT		(1 << 7)
+#define TERM_CAN_DELLINES	(1 << 8)
+#define TERM_CAN_INSLINES	(1 << 9)
+#define TERM_CAN_REPEAT		(1 << 10)
+#define TERM_CAN_BOLD		(1 << 11)
+#define TERM_CAN_BLINK		(1 << 12)
+#define TERM_CAN_UNDL		(1 << 13)
+#define TERM_CAN_REVERSE	(1 << 14)
+#define TERM_CAN_COLOR		(1 << 15)
+#define TERM_CAN_GCHAR		(1 << 16)
 
 extern	int	termfeatures;
 extern	struct	my_term	*current_term;
@@ -591,8 +593,8 @@ struct my_term {
 	/* non termcap/terminfo terminal info (generated by epic) */
 	char TI_normal[256];
 	const char *TI_sgrstrs[TERM_SGR_MAXVAL];
-	const char *TI_forecolors[16];
-	const char *TI_backcolors[16];
+	const char *TI_forecolors[256];
+	const char *TI_backcolors[256];
 	int TI_meta_mode;
 /*	int TI_need_redraw ; */
 };
@@ -617,8 +619,10 @@ int	tputs_x(char *);
 #define	term_bold_off()		outcap(BOLD_OFF)
 #define term_altcharset_on()	outcap(ALTCHAR_ON)
 #define term_altcharset_off()	outcap(ALTCHAR_OFF)
-#define term_set_foreground(x)	tputs_x(current_term->TI_forecolors[(x) & 0x0f])
-#define term_set_background(x)	tputs_x(current_term->TI_backcolors[(x) & 0x0f])
+#define term_italics_on()	outcap(ITALIC_ON)
+#define term_italics_off()	outcap(ITALIC_OFF)
+#define term_set_foreground(x)	tputs_x(current_term->TI_forecolors[(x) & 0xff])
+#define term_set_background(x)	tputs_x(current_term->TI_backcolors[(x) & 0xff])
 #define term_set_attribs(f,b)	tputs_x(term_getsgr(TERM_SGR_COLORS,(f),(b)))
 #define term_putgchar(x)	tputs_x(term_getsgr(TERM_SGR_GCHAR,(x),0))
 #define term_clear_screen()	term_clrscr()
