@@ -294,21 +294,6 @@ CTCP_HANDLER(do_crypto)
 	return ret;
 }
 
-#if 0
-/*
- * CTCP UTC - Expands inline to your current time.
- *		Does not reply.
- */
-CTCP_HANDLER(do_utc)
-{
-	if (!args || !*args)
-		return malloc_strdup(empty_string);
-
-	return malloc_strdup(my_ctime(my_atol(args)));
-}
-#endif
-
-
 /*
  * CTCP ACTION - Creates a special "ACTION" level message
  * 		Does not reply.
@@ -385,173 +370,6 @@ CTCP_HANDLER(do_dcc)
 	return NULL;
 }
 
-
-
-#if 0
-/*************** REPLY-GENERATING CTCPS *****************/
-
-/*
- * do_clientinfo: performs the CLIENTINFO CTCP.  If args is empty, returns the
- * list of all CTCPs currently recognized by IRCII.  If an arg is supplied,
- * it returns specific information on that CTCP.  If a matching CTCP is not
- * found, an ERRMSG ctcp is returned 
- */
-CTCP_HANDLER(do_clientinfo)
-{
-	int	i;
-
-	if (args && *args)
-	{
-		if ((i = lookup_ctcp(args)) >= 0)
-			send_ctcp(0, from, "CLIENTINFO", "%s %s", CTCP_NAME(i), CTCP(i)->desc);
-		else
-			send_ctcp(0, from, "ERRMSG", "%s: %s is not a valid function", "CLIENTINFO", args);
-	}
-	else
-	{
-		char buffer[BIG_BUFFER_SIZE + 1];
-		*buffer = '\0';
-
-		for (i = 0; i < ctcp_bucket->numitems; i++)
-		{
-			const char *name = CTCP_NAME(i);
-			strlcat(buffer, name, sizeof buffer);
-			strlcat(buffer, " ", sizeof buffer);
-		}
-		send_ctcp(0, from, cmd, "%s :Use %s <COMMAND> to get more specific information", buffer, cmd);
-	}
-
-	return NULL;
-}
-
-/* do_version: does the CTCP VERSION command */
-CTCP_HANDLER(do_version)
-{
-	char	*tmp;
-
-	/*
-	 * The old way seemed lame to me... let's show system name and
-	 * release information as well.  This will surely help out
-	 * experts/gurus answer newbie questions.  -- Jake [WinterHawk] Khuon
-	 *
-	 * For the paranoid, UNAME_HACK hides the gory details of your OS.
-	 */
-#if defined(HAVE_UNAME) && !defined(UNAME_HACK)
-	struct utsname un;
-	const char	*the_unix;
-
-	if (uname(&un) < 0)
-		the_unix = "unknown";
-	else
-		the_unix = un.sysname;
-
-	/* We no longer show the detailed version of your OS. */
-	send_ctcp(0, from, cmd, "ircII %s %s - %s", irc_version, the_unix, 
-			(tmp = get_string_var(CLIENT_INFORMATION_VAR)) ? 
-				tmp : IRCII_COMMENT);
-#else
-	send_ctcp(0, from, cmd, "ircII %s *IX - %s", irc_version,
-			(tmp = get_string_var(CLIENT_INFORMATION_VAR)) ? 
-				tmp : IRCII_COMMENT);
-#endif
-	return NULL;
-}
-
-/* do_time: does the CTCP TIME command --- done by Veggen */
-CTCP_HANDLER(do_time)
-{
-	send_ctcp(0, from, cmd, "%s", my_ctime(time(NULL)));
-	return NULL;
-}
-
-/* do_userinfo: does the CTCP USERINFO command */
-CTCP_HANDLER(do_userinfo)
-{
-	char *tmp;
-
-	send_ctcp(0, from, cmd, "%s", (tmp = get_string_var(USER_INFORMATION_VAR)) ? tmp : "<No User Information>");
-	return NULL;
-}
-
-/*
- * do_echo: does the CTCP ECHO command. Does not send an error if the
- * CTCP was sent to a channel.
- */
-CTCP_HANDLER(do_echo)
-{
-	if (!is_channel(to))
-		send_ctcp(0, from, cmd, "%s", args);
-	return NULL;
-}
-
-CTCP_HANDLER(do_ping)
-{
-	send_ctcp(0, from, cmd, "%s", args ? args : empty_string);
-	return NULL;
-}
-
-
-/* 
- * Does the CTCP FINGER reply 
- */
-CTCP_HANDLER(do_finger)
-{
-	struct	passwd	*pwd;
-	time_t	diff;
-	char	*tmp;
-	char	*ctcpuser,
-		*ctcpfinger;
-	const char	*my_host;
-	char	userbuff[NAME_LEN + 1];
-	char	gecosbuff[NAME_LEN + 1];
-
-	if ((my_host = get_server_userhost(from_server)) &&
-			strchr(my_host, '@'))
-		my_host = strchr(my_host, '@') + 1;
-	else
-		my_host = hostname;
-
-	diff = time(NULL) - idle_time.tv_sec;
-
-	if (!(pwd = getpwuid(getuid())))
-		return NULL;
-
-#ifndef GECOS_DELIMITER
-#define GECOS_DELIMITER ','
-#endif
-
-#if defined(ALLOW_USER_SPECIFIED_LOGIN)
-	if ((ctcpuser = getenv("IRCUSER"))) 
-		strlcpy(userbuff, ctcpuser, sizeof userbuff);
-	else
-#endif
-	{
-		if (pwd->pw_name)
-			strlcpy(userbuff, pwd->pw_name, sizeof userbuff);
-		else
-			strlcpy(userbuff, "epic-user", sizeof userbuff);
-	}
-
-#if defined(ALLOW_USER_SPECIFIED_LOGIN)
-	if ((ctcpfinger = getenv("IRCFINGER"))) 
-		strlcpy(gecosbuff, ctcpfinger, sizeof gecosbuff);
-	else
-#endif
-	      if (pwd->pw_gecos)
-		strlcpy(gecosbuff, pwd->pw_gecos, sizeof gecosbuff);
-	else
-		strlcpy(gecosbuff, "Esteemed EPIC User", sizeof gecosbuff);
-	if ((tmp = strchr(gecosbuff, GECOS_DELIMITER)) != NULL)
-		*tmp = 0;
-
-	send_ctcp(0, from, cmd, "%s (%s@%s) Idle %ld second%s", 
-		gecosbuff, userbuff, my_host, diff, plural(diff));
-
-	return NULL;
-}
-#endif
-
-
 /* 
  * If we recieve a CTCP DCC REJECT in a notice, then we want to remove
  * the offending DCC request
@@ -575,51 +393,6 @@ CTCP_HANDLER(do_dcc_reply)
 	return NULL;
 }
 
-#if 0
-/*
- * Handles CTCP PING replies.
- */
-CTCP_HANDLER(do_ping_reply)
-{
-	Timeval t;
-	time_t 	tsec = 0, 
-		tusec = 0, 
-		orig;
-	char *	ptr;
-
-	if (!args || !*args)
-		return NULL;		/* This is a fake -- cant happen. */
-
-	orig = my_atol(args);
-	get_time(&t);
-
-	/* Reply must be between time we started and right now */
-	if (orig < start_time.tv_sec || orig > t.tv_sec)
-	{
-		say("Invalid CTCP PING reply [%s] dropped.", args);
-		return NULL;
-	}
-
-	tsec = t.tv_sec - orig;
-
-	if ((ptr = strchr(args, ' ')) || (ptr = strchr(args, '.')))
-	{
-		*ptr++ = 0;
-		tusec = t.tv_usec - my_atol(ptr);
-	}
-
-	/*
-	 * 'args' is a pointer to the inside of do_ctcp's 'the_ctcp' buffer
-	 * which is IRCD_BUFFER_SIZE bytes big; args points to (allegedly)
-	 * the sixth position.  But just be paranoid and assume half that, 
-	 * so we will always be safe.
-	 */
-	snprintf(args, IRCD_BUFFER_SIZE / 2, "%f seconds", 
-			(float)(tsec + (tusec / 1000000.0)));
-	return NULL;
-}
-#endif
-
 
 /************************************************************************/
 /*
@@ -1270,39 +1043,6 @@ int	init_ctcp (void)
 				"transmit simple_encrypted_data ciphertext using a sha256 key",
 				do_crypto, 	do_crypto, NULL, NULL );
 
-#if 0
-	/* Inline expando CTCPs */
-	add_ctcp("UTC", 		CTCP_ORDINARY,
-				"substitutes the local timezone",
-				do_utc, 	do_utc , NULL, NULL);
-
-	/* Classic response-generating CTCPs */
-	add_ctcp("VERSION", 		CTCP_ORDINARY,
-				"shows client type, version and environment",
-				do_version, 	NULL, NULL, NULL );
-	add_ctcp("PING", 		CTCP_ORDINARY,
-				"returns the arguments it receives",
-				do_ping, 	do_ping_reply, NULL, NULL );
-	add_ctcp("ECHO", 		CTCP_ORDINARY,
-				"returns the arguments it receives",
-				do_echo, 	NULL, NULL, NULL );
-	add_ctcp("CLIENTINFO", 		CTCP_ORDINARY,
-				"gives information about available CTCP commands",
-				do_clientinfo, 	NULL, NULL, NULL );
-	add_ctcp("USERINFO",		CTCP_ORDINARY,
-				"returns user settable information",
-				do_userinfo, 	NULL, NULL, NULL );
-	add_ctcp("ERRMSG", 		CTCP_ORDINARY,
-				"returns error messages",
-				do_echo, 	NULL, NULL, NULL);
-	add_ctcp("FINGER", 		CTCP_ORDINARY,
-				"shows real name, login name and idle time of user", 
-				do_finger, 	NULL, NULL, NULL );
-	add_ctcp("TIME", 		CTCP_ORDINARY,
-				"tells you the time on the user's host",
-				do_time, 	NULL, NULL, NULL );
-#endif
-
 	return 0;
 }
 
