@@ -106,6 +106,7 @@ STATUS_FUNCTION(status_test);
 STATUS_FUNCTION(status_swappable);
 STATUS_FUNCTION(status_activity);
 STATUS_FUNCTION(status_window_prefix);
+STATUS_FUNCTION(status_server_status);
 
 /* These are used as placeholders for some expandos */
 static	char	*mode_format 		= (char *) 0;
@@ -234,7 +235,8 @@ struct status_formats status_expandos[] = {
 { 3, 'S', status_server,        &server_format,     	&STATUS_SERVER_VAR },
 { 3, 'W', status_window,	NULL, 			NULL },
 { 3, '+', status_mode,		&mode_format,       	&STATUS_MODE_VAR },
-{ 4, 'S', status_server,        &server_format,     	&STATUS_SERVER_VAR }
+{ 4, 'S', status_server,        &server_format,     	&STATUS_SERVER_VAR },
+{ 5, 'S', status_server_status,	NULL,			NULL }
 };
 #define NUMBER_OF_EXPANDOS (sizeof(status_expandos) / sizeof(struct status_formats))
 
@@ -443,11 +445,11 @@ void	compile_status (Window *w, Status *s)
 		else
 		{
 			if (k == 0)
-			   s->line[k].raw = get_string_var(STATUS_FORMAT_VAR);
+			   malloc_strcpy(&s->line[k].raw, get_string_var(STATUS_FORMAT_VAR));
 			else if (k == 1)
-			   s->line[k].raw = get_string_var(STATUS_FORMAT1_VAR);
+			   malloc_strcpy(&s->line[k].raw, get_string_var(STATUS_FORMAT1_VAR));
 			else  /* (k == 2) */
-			   s->line[k].raw = get_string_var(STATUS_FORMAT2_VAR);
+			   malloc_strcpy(&s->line[k].raw, get_string_var(STATUS_FORMAT2_VAR));
 
 			build_status_format(s, k);
 		}
@@ -1135,6 +1137,14 @@ const	char	*n = NULL;
 	RETURN
 }
 
+STATUS_FUNCTION(status_server_status)
+{
+	const char *	state = NULL;
+
+	state = get_server_state_str(window->server);
+	return state ? state : "Unknown";
+}
+
 /*
  * Displays the 005 "NETWORK" value for the current server for the window.
  */
@@ -1328,7 +1338,7 @@ STATUS_FUNCTION(status_umode)
  */
 STATUS_FUNCTION(status_chanop)
 {
-	char	*text;
+	const char	*text;
 	const char *chan;
 
 	if (window->server == NOSERV ||
@@ -1351,9 +1361,9 @@ STATUS_FUNCTION(status_chanop)
  */
 STATUS_FUNCTION(status_ssl)
 {
-	char *text;
+	const char *text;
 
-	if (window->server != NOSERV && get_server_isssl(window->server) &&
+	if (window->server != NOSERV && get_server_ssl_enabled(window->server) &&
 		(text = get_string_var(STATUS_SSL_ON_VAR)))
 			return text;
 	else if ((text = get_string_var(STATUS_SSL_OFF_VAR)))
@@ -1428,7 +1438,7 @@ STATUS_FUNCTION(status_channel)
  */
 STATUS_FUNCTION(status_voice)
 {
-	char *text;
+	const char *text;
 	const char *chan;
 
 	if (window->server == NOSERV ||
@@ -1471,7 +1481,7 @@ STATUS_FUNCTION(status_mail)
  */
 STATUS_FUNCTION(status_insert_mode)
 {
-	char	*text;
+	const char	*text;
 
 	if (get_int_var(INSERT_MODE_VAR) && DISPLAY_ON_WINDOW &&
 	    (text = get_string_var(STATUS_INSERT_VAR)))
@@ -1485,7 +1495,7 @@ STATUS_FUNCTION(status_insert_mode)
  */
 STATUS_FUNCTION(status_overwrite_mode)
 {
-	char	*text;
+	const char	*text;
 
 	if (!get_int_var(INSERT_MODE_VAR) && DISPLAY_ON_WINDOW &&
 	    (text = get_string_var(STATUS_OVERWRITE_VAR)))
@@ -1500,7 +1510,7 @@ STATUS_FUNCTION(status_overwrite_mode)
  */
 STATUS_FUNCTION(status_away)
 {
-	char	*text;
+	const char	*text;
 
 	/*
 	 * If we're only on one server, only do this for the
@@ -1523,7 +1533,7 @@ STATUS_FUNCTION(status_away)
  */
 STATUS_FUNCTION(status_user)
 {
-	char *	text;
+	const char *	text;
 	int	i;
 
 	/* XXX Ick.  Oh well. */
@@ -1575,7 +1585,7 @@ STATUS_FUNCTION(status_user)
 
 STATUS_FUNCTION(status_hold)
 {
-	char *text;
+	const char *text;
 
 	if (window->holding_distance_from_display_ip > window->display_lines  ||
 	    window->scrollback_distance_from_display_ip > window->display_lines)
@@ -1586,7 +1596,7 @@ STATUS_FUNCTION(status_hold)
 
 STATUS_FUNCTION(status_holdmode)
 {
-	char *text;
+	const char *text;
 
 	/* If hold mode is on... */
 	if (window->holding_top_of_display)
@@ -1606,7 +1616,7 @@ STATUS_FUNCTION(status_holdmode)
 
 STATUS_FUNCTION(status_oper)
 {
-	char *text;
+	const char *text;
 
 	if (window->server != NOSERV && get_server_operator(window->server) &&
 	    (text = get_string_var(STATUS_OPER_VAR)) &&
@@ -1738,7 +1748,7 @@ STATUS_FUNCTION(status_position)
  */
 STATUS_FUNCTION(status_scrollback)
 {
-	char *stuff;
+	const char *stuff;
 
 	if (window->scrollback_top_of_display &&
 	    (stuff = get_string_var(STATUS_SCROLLBACK_VAR)))
@@ -1809,7 +1819,7 @@ STATUS_FUNCTION(status_test)
  */
 STATUS_FUNCTION(status_swappable)
 {
-	char *stuff;
+	const char *stuff;
 
 	if (!window->swappable && 
 	    (stuff = get_string_var(STATUS_NOSWAP_VAR)))
